from configCmtPack import *
import logging
logging.basicConfig(level=logging.INFO,
                    format='[%(levelname)s] %(message)s')
#log = logging.getLogger(__name__)
# CRITICAL: 50
# ERROR: 40
# WARNING: 30
# INFO: 20
# Debug: 10
# NOSET: 0
# log.setLevel(0)
#log.info("set the logging")
